@@ -1,8 +1,11 @@
 #!/usr/bin/python2
 
+import gi
+gi.require_version('MateDesktop', '2.0')
 from gi.repository import Gtk, Gdk, GLib
 from gi.repository import Pango
 from gi.repository import GObject
+from gi.repository import MateDesktop
 import os.path
 import shutil
 import re
@@ -10,10 +13,6 @@ from execute import *
 import xdg.DesktopEntry
 import xdg.Menu
 from filemonitor import monitor as filemonitor
-import ctypes
-from ctypes import *
-
-gtk = CDLL("libgtk-x11-2.0.so.0")
 
 class IconManager(GObject.GObject):
 
@@ -91,7 +90,7 @@ class IconManager(GObject.GObject):
             image = Gtk.Image()
             icon_found = False
             for theme in self.themes:
-                if theme.has_icon( realIconName ):
+                if theme.lookup_icon(realIconName, 0, Gtk.IconLookupFlags.FORCE_REGULAR):
                     icon_found = True
                     break
 
@@ -124,8 +123,8 @@ class easyButton( Gtk.Button ):
         self.set_size_request( buttonWidth, buttonHeight )
 
         Align1 = Gtk.Alignment.new( 0, 0.5, 1.0, 0 )
-        HBox1 = Gtk.HBox()
-        self.labelBox = Gtk.VBox( False, 2 )
+        HBox1 = Gtk.Box( orientation=Gtk.Orientation.HORIZONTAL )
+        self.labelBox = Gtk.Box( orientation=Gtk.Orientation.VERTICAL, spacing=2 )
 
 
         self.buttonImage = Gtk.Image()
@@ -135,7 +134,7 @@ class easyButton( Gtk.Button ):
         else:
             #[ iW, iH ] = iconManager.getIconSize( self.iconSize )
             self.buttonImage.set_size_request( self.iconSize, self.iconSize  )
-        self.image_box = Gtk.HBox()
+        self.image_box = Gtk.Box( orientation=Gtk.Orientation.HORIZONTAL )
         self.image_box.pack_start(self.buttonImage, False, False, 5)
         self.image_box.show_all()
         HBox1.pack_start( self.image_box, False, False, 0 )
@@ -163,7 +162,7 @@ class easyButton( Gtk.Button ):
         self.connections.append( self.connect( event, callback ) )
 
     def onRelease( self, widget ):
-        widget.set_state(Gtk.StateType.NORMAL)
+        widget.get_style_context().set_state( Gtk.StateFlags.NORMAL )
 
     def onDestroy( self, widget ):
         self.buttonImage.clear()
@@ -188,6 +187,7 @@ class easyButton( Gtk.Button ):
 
         label.set_ellipsize( Pango.EllipsizeMode.END )
         label.set_alignment( 0.0, 1.0 )
+        label.set_max_width_chars(0)
         label.show()
         self.labelBox.pack_start( label , True, True, 0)
 
@@ -233,11 +233,6 @@ class easyButton( Gtk.Button ):
             #[ iW, iH ] = iconManager.getIconSize( self.iconSize )
             self.buttonImage.set_size_request( self.iconSize, self.iconSize  )
 
-class TargetEntry(Structure):
-     _fields_ = [("target", c_char_p),
-                 ("flags", c_int),
-                 ("info", c_int)]
-
 class ApplicationLauncher( easyButton ):
 
     def __init__( self, desktopFile, iconSize):
@@ -271,17 +266,13 @@ class ApplicationLauncher( easyButton ):
         # Drag and Drop
         self.connectSelf( "drag-data-get", self.dragDataGet )
 
-        array = TargetEntry * 2
-        targets = array(( "text/plain", 0, 100 ), ( "text/uri-list", 0, 101 ))
-        gtk.gtk_drag_source_set.argtypes = [c_void_p, c_ushort, c_void_p, c_int, c_ushort]
-        gtk.gtk_drag_source_set(hash(self), Gdk.ModifierType.BUTTON1_MASK, targets, 2, Gdk.DragAction.COPY)
+        targets = ( Gtk.TargetEntry.new( "text/plain", 0, 100 ), Gtk.TargetEntry.new( "text/uri-list", 0, 101 ) )
+        self.drag_source_set( Gdk.ModifierType.BUTTON1_MASK, targets, Gdk.DragAction.COPY )
 
         icon = self.getIcon( Gtk.IconSize.DND )
         if icon:
             iconName, s = icon.get_icon_name()
-            c = c_char_p(iconName.decode('utf-8', 'ignore').encode('ascii', 'ignore'))
-            gtk.gtk_drag_source_set_icon_name.argtypes = [c_void_p, c_char_p]
-            gtk.gtk_drag_source_set_icon_name( hash(self), c)
+            self.drag_source_set_icon_name( iconName )
 
         self.connectSelf( "focus-in-event", self.onFocusIn )
         self.connectSelf( "focus-out-event", self.onFocusOut )
@@ -398,9 +389,7 @@ class ApplicationLauncher( easyButton ):
         icon = self.getIcon( Gtk.IconSize.DND )
         if icon:
             iconName, size = icon.get_icon_name()
-            c = c_char_p(iconName.encode('ascii', 'ignore'))
-            gtk.gtk_drag_source_set_icon_name.argtypes = [c_void_p, c_char_p]
-            gtk.gtk_drag_source_set_icon_name( hash(self), c)
+            self.drag_source_set_icon_name( iconName )
 
     def startupFileChanged( self, *args ):
         self.inStartup = os.path.exists( self.startupFilePath )
@@ -413,11 +402,11 @@ class ApplicationLauncher( easyButton ):
         shutil.copyfile( self.desktopFile, self.startupFilePath )
 
         # Remove %u, etc. from Exec entry, because MATE will not replace them when it starts the app
-        item = matedesktop.item_new_from_uri( self.startupFilePath, matedesktop.LOAD_ONLY_IF_EXISTS )
+        item = MateDesktop.DesktopItem.new_from_uri(self.startupFilePath, MateDesktop.DesktopItemLoadFlags.ONLY_IF_EXISTS)
         if item:
             r = re.compile("%[A-Za-z]");
-            tmp = r.sub("", item.get_string( matedesktop.KEY_EXEC ) ).strip()
-            item.set_string( matedesktop.KEY_EXEC, tmp )
+            tmp = r.sub("", item.get_string( MateDesktop.DESKTOP_ITEM_EXEC ) ).strip()
+            item.set_string( MateDesktop.DESKTOP_ITEM_EXEC, tmp )
             item.save( self.startupFilePath, 0 )
 
     def removeFromStartup( self ):
@@ -493,7 +482,7 @@ class MenuApplicationLauncher( ApplicationLauncher ):
         appComment = self.appComment
         if self.highlight:
             try:
-                #color = self.labelBox.rc_get_style().fg[ Gtk.StateType.SELECTED ].to_string()
+                #color = self.labelBox.get_style_context().get_color( Gtk.StateFlags.SELECTED ).to_string()
                 #if len(color) > 0 and color[0] == "#":
                     #appName = "<span foreground=\"%s\"><b>%s</b></span>" % (color, appName);
                     #appComment = "<span foreground=\"%s\"><b>%s</b></span>" % (color, appComment);
